/* ========================================================================= *
 * JTilePile (C) 2008 by V.Termanis                                          *
 * TilePile game concept (C) 2008 by J.Mitchell                              *
 * ========================================================================= */
package JTP;

/**
 * Wrapper for <code>Tile</code> used in-game.
 * @author V.Termanis
 */
public class GameTile {

  private int height;
  // Having a 2nd copy here means whole Tile array doesn't have to be copied.
  private Tile tile;
  private boolean disabled;

  /**
   * Creates a new <code>GameTile</code> instance with the given from the given
   * <code>Tile</code>. Note: No copy is made of the original <code>Tile</code>
   * @param tile the tile to wrap
   * @throws NullPointerException if <code>tile</code> is <code>null</code>
   */
  public GameTile(Tile tile) throws NullPointerException {
    if (tile == null) {
      throw new NullPointerException("tile is null");
    }
    // no copy needed as used "read-only"
    this.tile = tile;
    height = tile.getHeight();
    disabled = false;
  }


  /**
   * Returns the height of this tile pile.
   * @return height of this pile
   */
  public int getHeight() {
    return height;
  }


  /**
   * Returns whether a player has died here.
   * @return <code>true</code> if either of the players has died here.
   */
  public boolean isDisabled() {
    return disabled;
  }


  /**
   * Sets disable flag for this tile. Note: Using the <code>reset()</code>
   * method will clear this flag.
   */
  public void disable() {
    disabled = true;
  }


  /**
   * Returns the type of tile.
   * Note: See <code>Tile</code> class for possible types.
   * @return the type of this tile
   */
  public int getType() {
    return tile.getType();
  }
  

  /**
   * Returns the tile within this wrapper.
   * @return the original tile
   */
  public Tile getTile() {
    return tile;
  }



  /**
   * Decreases height of this tile by one. Note: The height of the referenced
   * <code>Tile</code> instance is not altered. Using the <code>reset()</code>
   * method will return this tile to its original height.
   * @return <code>true</code> if height has changed
   */
  public boolean decHeight() {
    if (height > 0) {
      height -= 1;
      return true;
    }
    return false;
  }


  /**
   * Resets height specified in wrapper to that of the referenced
   * <code>Tile</code> instance.
   */
  public void reset() {
    height = tile.getHeight();
    disabled = false;
  }

}