/* ========================================================================= *
 * JTilePile (C) 2008 by V.Termanis                                          *
 * TilePile game concept (C) 2008 by J.Mitchell                              *
 * ========================================================================= */
package JTP;

import java.io.File;
import javax.swing.*;
import javax.swing.filechooser.*;

/**
 * Custom file filter for levelset open/save dialogs
 * @author V.Termanis
 */
public class LevelSetFilter extends FileFilter {

  private String ext;


  /**
   * Constructs a new <code>LevelSetFilter</code> with the given extension.
   * @param extension to filter by
   * @throws NullPointerException if <code>extension</code> is
   * <code>null</code>
   */
  public LevelSetFilter (String extension) throws NullPointerException {
    if (extension == null) {
      throw new NullPointerException("extension is null");
    }
    this.ext = extension;
  }


  /**
   * Determines whether a particular file is to be listed or not
   * @param f file to check
   * @return <code>true</code> if the supplied file has a valid extension
   */
  public boolean accept(File f) {
    if (f.isDirectory()) {
      return true;
    }
    String extension = getExtension(f);
    if (extension != null) {
      if (extension.equals(ext)) {
	return true;
      } else {
	return false;
      }
    }
    return false;
  }


  /**
   * Provides description for this file filter
   * @return description of this filter
   */ 
  public String getDescription() {
    return "JTilePile Level Sets";
  }


  /**
   * Extracts extension from a file
   */
  private String getExtension(File f) {
    String ext = null;
    String s = f.getName();
    int i = s.lastIndexOf('.');
    
    if (i > 0 &&  i < s.length() - 1) {
      ext = s.substring(i+1).toLowerCase();
    }
    return ext;
  }

}