/* ========================================================================= *
 * JTilePile (C) 2008 by V.Termanis                                          *
 * TilePile game concept (C) 2008 by J.Mitchell                              *
 * ========================================================================= */
package JTP;

import javax.swing.*;
import java.io.File;
import com.jgoodies.looks.plastic.PlasticXPLookAndFeel;
import com.jgoodies.looks.plastic.theme.LightGray;


/**
 * Class from which <code>JTP</code> is launched as an applet.
 * @author V.Termanis
 */
public class MainApplet extends JApplet {

  /**
   * Applet entry point.
   */
  public void init() {
    // so other components know the game is being run as an applet
    Main.setAppletMode();

    /* applets do not support splash screens at the moment but simple
     * progress indicator to STDOUT will still be made
     */
    SplashControl splash = new SplashControl(26, Main.progressColor,
					     Main.progressHeight);

    showStatus("Tile Pile Applet v" + Main.version + " loading...");
    System.out.println("JTilePile v" + Main.version + "\n\n" +
		       Main.cpMessage + "\n");
    splash.updateProgress();

    // JGoodies Look&Feel
    Main.setCustomLookAndFeel();
    splash.updateProgress();


    ProgressHandler.setProgressFilePath(getProgressPath());
    // indicate to user where progress will be saved
    try {
      System.out.println("Progress will be saved to " +
			 (new File(ProgressHandler.getProgressFilePath())).
			 getAbsolutePath());
    } catch (SecurityException e) {
      System.out.println("Progress will be saved to " +
			 ProgressHandler.getProgressFilePath());
    }

    // check whether to up/down - scale the applet
    double scaleFactor = 1;
    String paramStr = getParameter("scale");
    if (paramStr != null) {
      try {
	scaleFactor = Double.parseDouble(paramStr);
	System.out.println("Scale: " + (scaleFactor * 100) + "%");
      } catch (NumberFormatException e) {
	System.out.println("Warning: Invalid scale factor specified");
      }
    }

    // turn global antialiasing on?
    paramStr = getParameter("hq");
    if (paramStr != null && paramStr.toLowerCase().equals("true")) {
      if (!Main.setProperty("JTP.RenderQuality",
			    Integer.toString(ScreenFrames.
					     RENDERING_QUALITY))) {
	System.out.println("Warning: Failed to enable quality mode.");
      } else {
	System.out.println("High quality scaling enabled");
      }
    }

    Screen screen = new Screen(scaleFactor);
    add(screen);
    splash.updateProgress();    

    try {
      screen.start(splash);
      /* make top level applet component forward key presses, not just the
       * underlying Canvas (Screen)
       */
      addKeyListener(screen.getKeyHandler());
    } catch (Exception e) {
      System.out.println();
      e.printStackTrace();
      JOptionPane.showMessageDialog(this, "A fatal error occured:\n\n" +
				    e.getMessage() + "\n" +
				    Main.stackTraceToString(e),
				    "Tile Pile v" + Main.version + " Error",
				    JOptionPane.ERROR_MESSAGE);
    }
  }


  /**
   * Called once applet has been initalised.
   */
  public void start() {
    showStatus("Tile Pile Applet v" + Main.version + " started");
  }


  /**
   * Chooses a suitable path for the progress file in applet mode
   */
  private String getProgressPath() {
    String pPath = ".TilePile.APPLET_Progress";

    /**
     * Under Linux (Firefox & Opera) the default directory seems to be
     * /home/user which is fine, but under Windows using IE the default
     * directory is %USERPROFILE%\Desktop and using Opera it is
     * %PROGRAMFILES%\Opera! Since Applets are not permitted to read the
     * user.home property try to figure out where the user profile directory
     * lives (via environment), otherwise try to use temporary directory
     */
    try {
      String dir = null;
      
      if (System.getProperty("os.name").toLowerCase().
	  indexOf("windows") != -1) {
	dir = System.getenv("USERPROFILE");
	if (dir == null) {
	  dir = System.getenv("HOMEPATH");
	  if (dir == null) {
	    dir = System.getenv("TEMP");
	    if (dir == null) {
	      dir = System.getenv("TMP");
	      if (dir == null) {
		dir = ".";
	      }
	    }
	  }
	}
	pPath = dir + System.getProperty("file.separator") + pPath;
      }
    } catch (SecurityException e) {
      System.out.println("Warning: Not enough permissions to find out where " +
			 "user profile lives, using default directory.");
    }
    return pPath;
  }

}
