/* ========================================================================= *
 * JTilePile (C) 2008 by V.Termanis                                          *
 * TilePile game concept (C) 2008 by J.Mitchell                              *
 * ========================================================================= */
package JTP;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.ImageIcon;
 
/**
 * Slightly changed <code>JFrame</code> to prevent accidental closing of
 * <code>JTP</code>
 * @author V.Termanis
 */
public class NonClosingJFrame extends JFrame {
  // so can register Screen class instance to WindowStatus class (focus)
  private WindowStatus windowStatus;


  public NonClosingJFrame(String s) {
    super(s);
    setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
    windowStatus = new WindowStatus();
    addWindowListener(windowStatus);
  }


  /**
   * Registers <code>Screen</code> instance so icon for close dialog
   * can be read
   * @param screen initiated instance
   */
  public void registerScreen(Screen screen) throws NullPointerException {
    if (screen == null) {
      throw new NullPointerException("screen is null");
    }
    windowStatus.registerScreen(screen);
  }


  private class WindowStatus extends WindowAdapter {
    // so can inform the main Canvas when it gains / loses focus
    private Screen screen;


    public void windowClosing(WindowEvent e) {
      ImageIcon icon = 
	(screen == null) ? null :
	screen.getImageData().getIcon(Images.O_QUESTION);
      if (JOptionPane.
	  showOptionDialog(NonClosingJFrame.this,
			   "Are you sure you want to quit Tile Pile?",
			   "Tile Pile", JOptionPane.YES_NO_OPTION,
			   JOptionPane.QUESTION_MESSAGE,
			   icon, null, null) == JOptionPane.YES_OPTION) {
	System.exit(0);
	}
    }


    public void registerScreen(Screen screen) throws NullPointerException {
      if (screen == null) {
	throw new NullPointerException("screen is null");
      }
      this.screen = screen;
    }


    public void windowDeactivated(WindowEvent e) {
      if (screen != null) {
	screen.handleDeactivation();
      }
    }

  }
}