/* ========================================================================= *
 * JTilePile (C) 2008 by V.Termanis                                          *
 * TilePile game concept (C) 2008 by J.Mitchell                              *
 * ========================================================================= */
package JTP;

import java.awt.*;
import java.awt.image.BufferedImage;
import java.net.URL;
import java.security.AccessControlException;

/**
 * Class to handle start-up splash animation
 * @author V.Termanis
 */
public class SplashControl {

  private SplashScreen splash;
  private BufferedImage splashImage;
  private Color progressColor;
  private int totalSteps, currentStep, progressHeight;
  private Graphics2D g;


  /**
   * Constructs a new <code>SplashControl</code> instance with the specified
   * parameters.
   * @param progressSteps number of steps to "fill" up logo in
   * @param progressColor color in which to overlay logo with
   */
  public SplashControl(int progressSteps, Color progressColor,
		       int progressHeight) {
    try {
      splash = SplashScreen.getSplashScreen();
    } catch (AccessControlException e) {
      System.out.println("Warning: Access denied to splash screen");
    }
    if (splash != null) {
      g = splash.createGraphics();
    }
    totalSteps = progressSteps;
    this.progressColor = progressColor;
    this.progressHeight = progressHeight;
    currentStep = 0;
  }

  
  /**
   * Advances logo overlay "fill" to next step. Note: This will have no effect
   * anymore once it has been called <code>progressSteps</code> number of times
   */
  public void updateProgress() {
    if (splash != null) {
      if (g != null && currentStep < totalSteps) {
	currentStep++;
	if (splashImage == null) {
	  try {
	    splashImage = ImageLoader.loadImage(splash.getImageURL());
	    // should never happen
	  } catch (Exception e) {
	    System.out.println("Warning: Could not load splash screen image");
	    return;
	  }
	}
	
	g.drawImage(splashImage, null, 0, 0);
	g.setColor(progressColor);
	g.fillRect(0, 0,
		   (int) Math.round(splash.getSize().width *
				    ((double) currentStep / totalSteps)),
		   progressHeight);
	g.setPaintMode();
	splash.update();
      }
      // show loading indicator in STDOUT if no splash screen available
    } else {
      System.out.print('.');
    }
  }

}