/* ========================================================================= *
 * JTilePile (C) 2008 by V.Termanis                                          *
 * TilePile game concept (C) 2008 by J.Mitchell                              *
 * ========================================================================= */
package JTP;

import java.awt.Point;

/**
 * Teleportation tile
 * @author V.Termanis
 */
public class TptTile extends Tile {

  /**
   * Destination of this teleport pile
   */
  private Point destination;


  /**
   * Constructs a new <code>TptTile</code> instance with the given attributes.
   * @param height of the pile
   * @param destination of this teleport
   * @throws NullPointerException if <code>destination</code> is
   * <code>null</code>.
   * @throws TileException if either <code>height</code> or <code>destination
   * </code>are invalid.
   */
  public TptTile(int height, Point destination)
    throws NullPointerException, TileException {
    
    this.height = height;
    tileCheck();
    this.destination = new Point(destination);
    tptCheck();
    type = TELEPORT;
  }


  /**
   * Used to check for teleport destination validity upon creation.
   * @throws NullPointerException if <code>destination</code> is
   * <code>null</code>.
   * @throws TileException if <code>destination</code> is otherwise invalid
   * (i.e. either of coordinates is negative).
   */
  private void tptCheck() throws TileException, NullPointerException {
    if (destination == null) {
      throw new NullPointerException("destination is null");
    }
    if (destination.x < 0 || destination.y < 0) {
      throw new TileException ("TptTile: Invalid destination coordinates");
    }
  }


  /**
   * Returns destination of this teleport tile as a <code>Point</code>.
   * @return the destination of this teleport tile.
   */
  public Point getDestination() {
    return destination;
  }


  /**
   * Returns destination of a teleport tile as a <code>Point</code>.
   * @param t the tile of which destination is to be determined.
   * @return the destination of this teleport tile, or <code>null</code> if
   * the supplied tile is not of type <code>TELEPORT</code>.
   */
  public static Point getDestination(Tile t) {
    if (t.getType() == TELEPORT) {
      return ((TptTile) t).getDestination();
    } else {
      return null;
    }
  }

  
  /**
   * Used to compare two tiles, ignoring their respective heights.
   * @param t the <code>Tile</code> instance to compare the current tile with.
   * @return <code>true</code> if the two <code>Tile</code> instances
   * are equal disregarding their heights.
   */
  public boolean equalsApartFromHeight(Tile t) {
    if (t.getType() == TELEPORT) {
      return destination.equals(((TptTile) t).getDestination());
    } else {
      return false;
    }
  }


  /**
   * Creates an exact (non-shallow) copy of the current tile
   * @return a copy of the <code>Tile</code> instance.
   */
  public Tile copy() {
    try {
      return new TptTile(height, destination);
      // this should never happen
    }	catch (Exception e) {
      e.printStackTrace();
    }
    return null;
  }

}